@@ -19,24 +19,28 @@ use std::sync::{Arc, Mutex, RwLock};
 use std::time::Duration;
 
 use cylinder::VerifierFactory;
-#[cfg(any(feature = "postgres", feature = "sqlite"))]
+#[cfg(all(
+    feature = "receipt-store",
+    any(feature = "postgres", feature = "sqlite")
+))]
 use diesel::r2d2::{ConnectionManager, Pool};
 use openssl::hash::{hash, MessageDigest};
 #[cfg(all(
-    feature = "diesel-receipt-store",
+    feature = "receipt-store",
     any(feature = "postgres", feature = "sqlite")
 ))]
 use sawtooth::receipt::store::diesel::DieselReceiptStore;
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 use sawtooth::receipt::store::{lmdb::LmdbReceiptStore, ReceiptStore};
-#[cfg(not(feature = "diesel-receipt-store"))]
+#[cfg(not(feature = "receipt-store"))]
 use sawtooth::store::{lmdb::LmdbOrderedStore, receipt_store::TransactionReceiptStore};
+#[cfg(feature = "service-arg-validation")]
+use splinter::error::InvalidArgumentError;
 use splinter::error::{InternalError, InvalidStateError};
 #[cfg(feature = "service-arg-validation")]
-use splinter::service::validation::{ServiceArgValidationError, ServiceArgValidator};
+use splinter::service::validation::ServiceArgValidator;
 use splinter::service::{FactoryCreateError, Service, ServiceFactory};
 
-#[cfg(feature = "service-arg-validation")]
 use crate::hex::parse_hex;
 use crate::hex::to_hex;
 
@@ -48,13 +52,13 @@ const DEFAULT_STATE_DB_SIZE: usize = 1 << 30; // 1024 ** 3
 const DEFAULT_RECEIPT_DB_DIR: &str = "/var/lib/splinter";
 const DEFAULT_RECEIPT_DB_SIZE: usize = 1 << 30; // 1024 ** 3
 
-#[cfg(not(feature = "diesel-receipt-store"))]
+#[cfg(not(feature = "receipt-store"))]
 type ScabbardReceiptStore = Arc<RwLock<TransactionReceiptStore>>;
 
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 type ScabbardReceiptStore = Arc<RwLock<dyn ReceiptStore>>;
 
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 pub enum ConnectionUri {
     #[cfg(feature = "postgres")]
     Postgres(Box<str>),
@@ -71,7 +75,7 @@ pub enum ScabbardStorageConfiguration {
         db_dir: Option<String>,
         db_size: Option<usize>,
     },
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     DatabaseConnectionUri { connection_uri: ConnectionUri },
 }
 
@@ -84,7 +88,7 @@ impl ScabbardStorageConfiguration {
     }
 
     #[cfg(all(
-        feature = "diesel-receipt-store",
+        feature = "receipt-store",
         any(feature = "postgres", feature = "sqlite")
     ))]
     fn connection_uri(connection_uri: &str) -> Self {
@@ -105,7 +109,7 @@ impl ScabbardStorageConfiguration {
                 db_dir: Some(db_dir),
                 db_size,
             },
-            #[cfg(feature = "diesel-receipt-store")]
+            #[cfg(feature = "receipt-store")]
             _ => Self::Lmdb {
                 db_dir: Some(db_dir),
                 db_size: None,
@@ -119,7 +123,7 @@ impl ScabbardStorageConfiguration {
                 db_dir,
                 db_size: Some(db_size),
             },
-            #[cfg(feature = "diesel-receipt-store")]
+            #[cfg(feature = "receipt-store")]
             _ => Self::Lmdb {
                 db_dir: None,
                 db_size: Some(db_size),
@@ -179,7 +183,7 @@ impl ScabbardFactoryBuilder {
     }
 
     #[cfg(all(
-        feature = "diesel-receipt-store",
+        feature = "receipt-store",
         any(feature = "postgres", feature = "sqlite")
     ))]
     /// Sets the receipt db connection url to be used by the resulting factory.
@@ -231,7 +235,7 @@ impl ScabbardFactoryBuilder {
                     db_size: db_size.unwrap_or(DEFAULT_RECEIPT_DB_SIZE),
                 }
             }
-            #[cfg(feature = "diesel-receipt-store")]
+            #[cfg(feature = "receipt-store")]
             ScabbardStorageConfiguration::DatabaseConnectionUri { connection_uri } => {
                 match connection_uri {
                     #[cfg(feature = "postgres")]
@@ -291,7 +295,7 @@ impl ScabbardFactoryBuilder {
                 db_dir.unwrap_or_else(|| DEFAULT_STATE_DB_DIR.into()),
                 db_size.unwrap_or(DEFAULT_STATE_DB_SIZE),
             ),
-            #[cfg(feature = "diesel-receipt-store")]
+            #[cfg(feature = "receipt-store")]
             _ => unreachable!(),
         };
 
@@ -311,11 +315,11 @@ enum ScabbardFactoryStorageConfig {
         db_dir: String,
         db_size: usize,
     },
-    #[cfg(feature = "postgres")]
+    #[cfg(all(feature = "receipt-store", feature = "postgres"))]
     Postgres {
         pool: Pool<ConnectionManager<diesel::pg::PgConnection>>,
     },
-    #[cfg(feature = "sqlite")]
+    #[cfg(all(feature = "receipt-store", feature = "sqlite"))]
     Sqlite {
         pool: Pool<ConnectionManager<diesel::SqliteConnection>>,
     },
@@ -334,36 +338,58 @@ pub struct ScabbardArgValidator;
 
 #[cfg(feature = "service-arg-validation")]
 impl ServiceArgValidator for ScabbardArgValidator {
-    fn validate(&self, args: &HashMap<String, String>) -> Result<(), ServiceArgValidationError> {
+    fn validate(&self, args: &HashMap<String, String>) -> Result<(), InvalidArgumentError> {
         let peer_services_str = args.get("peer_services").ok_or_else(|| {
-            ServiceArgValidationError("peer_services argument not provided".into())
+            InvalidArgumentError::new("peer_services".into(), "argument not provided".into())
         })?;
 
-        serde_json::from_str::<Vec<String>>(peer_services_str).map_err(|err| {
-            ServiceArgValidationError(format!("failed to parse peer_services list: {}", err,))
+        let peer_services = parse_list(peer_services_str).map_err(|err| {
+            InvalidArgumentError::new(
+                "peer_services".into(),
+                format!("failed to parse list: {}", err,),
+            )
         })?;
 
-        let admin_keys_str = args
-            .get("admin_keys")
-            .ok_or_else(|| ServiceArgValidationError("admin_keys argument not provided".into()))?;
+        for service in peer_services {
+            if service.is_empty() {
+                return Err(InvalidArgumentError::new(
+                    "peer_services".into(),
+                    "must provide at least one service ID".into(),
+                ));
+            }
+        }
+
+        let admin_keys_str = args.get("admin_keys").ok_or_else(|| {
+            InvalidArgumentError::new("admin_keys".into(), "argument not provided".into())
+        })?;
 
         let admin_keys = parse_list(admin_keys_str).map_err(|err| {
-            ServiceArgValidationError(format!("failed to parse admin_keys list: {}", err,))
+            InvalidArgumentError::new(
+                "admin_keys".into(),
+                format!("failed to parse list: {}", err,),
+            )
         })?;
 
         for key in admin_keys {
+            if key.is_empty() {
+                return Err(InvalidArgumentError::new(
+                    "admin_keys".into(),
+                    "must provide at least one admin key".into(),
+                ));
+            }
+
             let key_bytes = parse_hex(&key).map_err(|_| {
-                ServiceArgValidationError(format!(
-                    "{:?} is not a valid hex-formatted public key",
-                    key,
-                ))
+                InvalidArgumentError::new(
+                    "admin_keys".into(),
+                    format!("{:?} is not a valid hex-formatted public key", key,),
+                )
             })?;
 
             if key_bytes.len() != 33 {
-                return Err(ServiceArgValidationError(format!(
-                    "{} is not a valid public key: invalid length",
-                    key
-                )));
+                return Err(InvalidArgumentError::new(
+                    "admin_keys".into(),
+                    format!("{} is not a valid public key: invalid length", key),
+                ));
             }
         }
 
@@ -420,6 +446,22 @@ impl ServiceFactory for ScabbardFactory {
             ))
         })?;
 
+        for key in admin_keys.iter() {
+            let key_bytes = parse_hex(key).map_err(|_| {
+                FactoryCreateError::InvalidArguments(format!(
+                    "{:?} is not a valid hex-formatted public key",
+                    key,
+                ))
+            })?;
+
+            if key_bytes.len() != 33 {
+                return Err(FactoryCreateError::InvalidArguments(format!(
+                    "{} is not a valid public key: invalid length",
+                    key
+                )));
+            }
+        }
+
         let coordinator_timeout = args
             .get("coordinator_timeout")
             .map(|timeout| match timeout.parse::<u64>() {
@@ -433,12 +475,12 @@ impl ServiceFactory for ScabbardFactory {
         let version = ScabbardVersion::try_from(args.get("version").map(String::as_str))
             .map_err(FactoryCreateError::InvalidArguments)?;
 
-        let state_db_path = compute_db_path(&service_id, circuit_id, state_db_dir, "-state")?;
+        let state_db_path = compute_db_path(&service_id, circuit_id, state_db_dir, "state")?;
 
         let (receipt_store, receipt_purge): (ScabbardReceiptStore, _) = match &self
             .receipt_store_factory_config
         {
-            #[cfg(not(feature = "diesel-receipt-store"))]
+            #[cfg(not(feature = "receipt-store"))]
             ScabbardFactoryStorageConfig::Lmdb { db_dir, db_size } => {
                 let receipt_db_path =
                     compute_db_path(&service_id, circuit_id, Path::new(&db_dir), "-receipts")?;
@@ -457,12 +499,12 @@ impl ServiceFactory for ScabbardFactory {
                         as Box<dyn Fn() -> Result<(), InternalError> + Sync + Send>,
                 )
             }
-            #[cfg(feature = "diesel-receipt-store")]
+            #[cfg(feature = "receipt-store")]
             ScabbardFactoryStorageConfig::Lmdb { db_dir, db_size } => {
                 let receipt_db_dir_path = Path::new(&db_dir);
 
                 let receipt_db_path =
-                    compute_db_path(&service_id, circuit_id, receipt_db_dir_path, "-receipts")?;
+                    compute_db_path(&service_id, circuit_id, receipt_db_dir_path, "receipts")?;
 
                 let file: String = receipt_db_path
                     .with_extension("lmdb")
@@ -498,23 +540,29 @@ impl ServiceFactory for ScabbardFactory {
                         as Box<dyn Fn() -> Result<(), InternalError> + Sync + Send>,
                 )
             }
-            #[cfg(all(feature = "diesel-receipt-store", feature = "postgres"))]
+            #[cfg(all(feature = "receipt-store", feature = "postgres"))]
             ScabbardFactoryStorageConfig::Postgres { pool } => (
-                Arc::new(RwLock::new(DieselReceiptStore::new(pool.clone()))),
+                Arc::new(RwLock::new(DieselReceiptStore::new(
+                    pool.clone(),
+                    Some(format!("{}::{}", circuit_id, service_id)),
+                ))),
                 Box::new(|| Ok(())) as Box<dyn Fn() -> Result<(), InternalError> + Sync + Send>,
             ),
-            #[cfg(all(feature = "diesel-receipt-store", feature = "sqlite"))]
+            #[cfg(all(feature = "receipt-store", feature = "sqlite"))]
             ScabbardFactoryStorageConfig::Sqlite { pool } => (
-                Arc::new(RwLock::new(DieselReceiptStore::new(pool.clone()))),
+                Arc::new(RwLock::new(DieselReceiptStore::new(
+                    pool.clone(),
+                    Some(format!("{}::{}", circuit_id, service_id)),
+                ))),
                 Box::new(|| Ok(())) as Box<dyn Fn() -> Result<(), InternalError> + Sync + Send>,
             ),
             #[cfg(all(
-                feature = "diesel-receipt-store",
+                feature = "receipt-store",
                 not(any(feature = "postgres", feature = "sqlite"))
             ))]
             _ => {
                 return Err(FactoryCreateError::Internal(
-                    "diesel-receipt-store was enabled, but without any databases".into(),
+                    "receipt-store was enabled, but without any databases".into(),
                 ))
             }
         };
@@ -634,7 +682,7 @@ fn purge_paths(lmdb_path: &Path) -> Result<(), InternalError> {
 mod tests {
     use super::*;
 
-    use cylinder::secp256k1::Secp256k1Context;
+    use cylinder::{secp256k1::Secp256k1Context, Context};
     use tempdir::TempDir;
 
     /// Verify that the scabbard factory produces a valid `Scabbard` instance.
@@ -656,7 +704,7 @@ mod tests {
     }
 
     /// Verify that the scabbard factory produces a valid `Scabbard` instance if the service
-    /// arguments are commo seperated instead of json fmt.
+    /// arguments are comma seperated instead of json fmt.
     #[test]
     fn create_successful_no_json() {
         let (_tempdir, factory) = get_factory();
@@ -719,14 +767,65 @@ mod tests {
         );
     }
 
+    /// Verify that `Scabbard` creation fails when the `admin_keys` argument isn't specified.
+    #[test]
+    fn create_with_invalid_admin_keys() {
+        let (_tempdir, factory) = get_factory();
+        let mut args = get_mock_args();
+        args.insert("admin_keys".to_string(), "bad_key".to_string());
+
+        assert!(
+            factory.create("".into(), "", "", args).is_err(),
+            "Creating factory with invalid admin keys did not fail"
+        );
+    }
+
+    /// Verify arg validation returns ok with valid common seperated Args
+    #[test]
+    #[cfg(feature = "service-arg-validation")]
+    fn test_valid_argument_validation_no_json() {
+        let validator = ScabbardArgValidator;
+        let args = get_mock_args_no_json();
+        assert!(validator.validate(&args).is_ok());
+    }
+
+    /// Verify arg validation returns ok with valid Args using json
+    #[test]
+    #[cfg(feature = "service-arg-validation")]
+    fn test_valid_argument_validation() {
+        let validator = ScabbardArgValidator;
+        let args = get_mock_args();
+        assert!(validator.validate(&args).is_ok());
+    }
+
+    /// Verify arg validation returns an error if the args are empty
+    #[test]
+    #[cfg(feature = "service-arg-validation")]
+    fn test_no_argument_validation() {
+        let validator = ScabbardArgValidator;
+        let args = HashMap::new();
+        assert!(validator.validate(&args).is_err());
+    }
+
+    /// Verify arg validation returns an error if the args are present but the values are empty
+    #[test]
+    #[cfg(feature = "service-arg-validation")]
+    fn test_empty_argument_validation() {
+        let validator = ScabbardArgValidator;
+        let mut args = HashMap::new();
+        args.insert("peer_services".into(), "".into());
+        args.insert("admin_keys".into(), "".into());
+        assert!(validator.validate(&args).is_err());
+    }
+
     fn get_factory() -> (TempDir, ScabbardFactory) {
         let tempdir = TempDir::new("scabbard_factory").expect("Unable to create new tempdir");
-        #[cfg(not(all(feature = "diesel-receipt-store", feature = "sqlite")))]
+        #[cfg(not(all(feature = "receipt-store", feature = "sqlite")))]
         let receipt_store_factory_config = ScabbardFactoryStorageConfig::Lmdb {
             db_dir: tempdir.path().to_string_lossy().into(),
             db_size: 1024 * 1024,
         };
-        #[cfg(all(feature = "diesel-receipt-store", feature = "sqlite"))]
+        #[cfg(all(feature = "receipt-store", feature = "sqlite"))]
         let receipt_store_factory_config = ScabbardFactoryStorageConfig::Sqlite {
             pool: {
                 let connection_manager =
@@ -758,7 +857,7 @@ mod tests {
 
     fn get_mock_args() -> HashMap<String, String> {
         let peer_services = vec!["1".to_string(), "2".to_string(), "3".to_string()];
-        let admin_keys: Vec<String> = vec![];
+        let admin_keys = vec![get_public_key(), get_public_key()];
         let mut args = HashMap::new();
         args.insert(
             "peer_services".into(),
@@ -774,7 +873,17 @@ mod tests {
     fn get_mock_args_no_json() -> HashMap<String, String> {
         let mut args = HashMap::new();
         args.insert("peer_services".into(), "0,1,3".into());
-        args.insert("admin_keys".into(), "".into());
+        args.insert(
+            "admin_keys".into(),
+            format!("{},{}", get_public_key(), get_public_key()),
+        );
         args
     }
+
+    fn get_public_key() -> String {
+        let context = Secp256k1Context::new();
+        let private_key = context.new_random_private_key();
+        let public_key = context.get_public_key(&private_key).unwrap();
+        public_key.as_hex()
+    }
 }
