@@ -33,9 +33,9 @@ use std::time::Duration;
 
 use cylinder::Verifier as SignatureVerifier;
 use protobuf::Message;
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 use sawtooth::receipt::store::ReceiptStore;
-#[cfg(not(feature = "diesel-receipt-store"))]
+#[cfg(not(feature = "receipt-store"))]
 use sawtooth::store::receipt_store::TransactionReceiptStore;
 use splinter::{
     consensus::{Proposal, ProposalUpdate},
@@ -86,10 +86,10 @@ impl TryFrom<Option<&str>> for ScabbardVersion {
     }
 }
 
-#[cfg(not(feature = "diesel-receipt-store"))]
+#[cfg(not(feature = "receipt-store"))]
 type ScabbardReceiptStore = Arc<RwLock<TransactionReceiptStore>>;
 
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 type ScabbardReceiptStore = Arc<RwLock<dyn ReceiptStore>>;
 
 /// A service for running Sawtooth Sabre smart contracts with two-phase commit consensus.
@@ -140,8 +140,17 @@ impl Scabbard {
             version,
         );
 
-        let state = ScabbardState::new(state_db_path, state_db_size, receipt_store, admin_keys)
-            .map_err(|err| ScabbardError::InitializationFailed(Box::new(err)))?;
+        let state = ScabbardState::new(
+            state_db_path,
+            state_db_size,
+            #[cfg(feature = "metrics")]
+            service_id.clone(),
+            #[cfg(feature = "metrics")]
+            circuit_id.to_string(),
+            receipt_store,
+            admin_keys,
+        )
+        .map_err(|err| ScabbardError::InitializationFailed(Box::new(err)))?;
 
         let coordinator_timeout =
             coordinator_timeout.unwrap_or_else(|| Duration::from_secs(DEFAULT_COORDINATOR_TIMEOUT));
@@ -512,16 +521,16 @@ pub mod tests {
     use std::path::PathBuf;
 
     use cylinder::{secp256k1::Secp256k1Context, VerifierFactory};
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     use sawtooth::receipt::store::{ReceiptIter, ReceiptStoreError};
-    #[cfg(not(feature = "diesel-receipt-store"))]
+    #[cfg(not(feature = "receipt-store"))]
     use sawtooth::store::lmdb::LmdbOrderedStore;
     use splinter::service::{
         ServiceConnectionError, ServiceDisconnectionError, ServiceMessageContext,
         ServiceNetworkSender, ServiceSendError,
     };
     use tempdir::TempDir;
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     use transact::protocol::receipt::TransactionReceipt;
 
     use crate::service::factory::compute_db_path;
@@ -542,12 +551,12 @@ pub mod tests {
             HashSet::new(),
             paths.state_db_path.as_path(),
             TEMP_DB_SIZE,
-            #[cfg(not(feature = "diesel-receipt-store"))]
+            #[cfg(not(feature = "receipt-store"))]
             Arc::new(RwLock::new(TransactionReceiptStore::new(Box::new(
                 LmdbOrderedStore::new(&paths.receipt_db_path, Some(TEMP_DB_SIZE))
                     .expect("Unable to make lmdb store"),
             )))),
-            #[cfg(feature = "diesel-receipt-store")]
+            #[cfg(feature = "receipt-store")]
             Arc::new(RwLock::new(MockReceiptStore)),
             Box::new(|| Ok(())),
             Secp256k1Context::new().new_verifier(),
@@ -572,12 +581,12 @@ pub mod tests {
             HashSet::new(),
             paths.state_db_path.as_path(),
             TEMP_DB_SIZE,
-            #[cfg(not(feature = "diesel-receipt-store"))]
+            #[cfg(not(feature = "receipt-store"))]
             Arc::new(RwLock::new(TransactionReceiptStore::new(Box::new(
                 LmdbOrderedStore::new(&paths.receipt_db_path, Some(TEMP_DB_SIZE))
                     .expect("Unable to make lmdb store"),
             )))),
-            #[cfg(feature = "diesel-receipt-store")]
+            #[cfg(feature = "receipt-store")]
             Arc::new(RwLock::new(MockReceiptStore)),
             Box::new(|| Ok(())),
             Secp256k1Context::new().new_verifier(),
@@ -602,12 +611,12 @@ pub mod tests {
             HashSet::new(),
             paths.state_db_path.as_path(),
             TEMP_DB_SIZE,
-            #[cfg(not(feature = "diesel-receipt-store"))]
+            #[cfg(not(feature = "receipt-store"))]
             Arc::new(RwLock::new(TransactionReceiptStore::new(Box::new(
                 LmdbOrderedStore::new(&paths.receipt_db_path, Some(TEMP_DB_SIZE))
                     .expect("Unable to make lmdb store"),
             )))),
-            #[cfg(feature = "diesel-receipt-store")]
+            #[cfg(feature = "receipt-store")]
             Arc::new(RwLock::new(MockReceiptStore)),
             Box::new(|| Ok(())),
             Secp256k1Context::new().new_verifier(),
@@ -622,7 +631,7 @@ pub mod tests {
         // this is deleted when dropped
         _temp_dir: TempDir,
         pub state_db_path: PathBuf,
-        #[cfg(not(feature = "diesel-receipt-store"))]
+        #[cfg(not(feature = "receipt-store"))]
         pub receipt_db_path: PathBuf,
     }
 
@@ -634,7 +643,7 @@ pub mod tests {
             let state_db_path =
                 compute_db_path(MOCK_SERVICE_ID, MOCK_CIRCUIT_ID, temp_dir.path(), "-state")
                     .expect("Failed to compute DB paths");
-            #[cfg(not(feature = "diesel-receipt-store"))]
+            #[cfg(not(feature = "receipt-store"))]
             let receipt_db_path = compute_db_path(
                 MOCK_SERVICE_ID,
                 MOCK_CIRCUIT_ID,
@@ -645,7 +654,7 @@ pub mod tests {
             Self {
                 _temp_dir: temp_dir,
                 state_db_path,
-                #[cfg(not(feature = "diesel-receipt-store"))]
+                #[cfg(not(feature = "receipt-store"))]
                 receipt_db_path,
             }
         }
@@ -785,10 +794,10 @@ pub mod tests {
         }
     }
 
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     struct MockReceiptStore;
 
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     impl ReceiptStore for MockReceiptStore {
         fn get_txn_receipt_by_id(
             &self,
