@@ -103,14 +103,14 @@ mod tests {
     use std::sync::{Arc, Mutex, RwLock};
 
     use cylinder::{secp256k1::Secp256k1Context, Context};
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     use diesel::r2d2::{ConnectionManager, Pool};
     use reqwest::{blocking::Client, StatusCode, Url};
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     use sawtooth::migrations::run_sqlite_migrations;
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     use sawtooth::receipt::store::diesel::DieselReceiptStore;
-    #[cfg(not(feature = "diesel-receipt-store"))]
+    #[cfg(not(feature = "receipt-store"))]
     use sawtooth::store::{lmdb::LmdbOrderedStore, receipt_store::TransactionReceiptStore};
     use serde_json::{to_value, Value as JsonValue};
     use tempdir::TempDir;
@@ -164,7 +164,7 @@ mod tests {
     fn state_with_prefix() {
         let paths = StatePaths::new("state_with_prefix");
 
-        #[cfg(not(feature = "diesel-receipt-store"))]
+        #[cfg(not(feature = "receipt-store"))]
         let receipt_store = Arc::new(RwLock::new(TransactionReceiptStore::new(Box::new(
             LmdbOrderedStore::new(
                 &StatePaths::new("state_at_address").receipt_db_path,
@@ -172,9 +172,10 @@ mod tests {
             )
             .expect("Failed to create LMDB store"),
         ))));
-        #[cfg(feature = "diesel-receipt-store")]
+        #[cfg(feature = "receipt-store")]
         let receipt_store = Arc::new(RwLock::new(DieselReceiptStore::new(
             create_connection_pool_and_migrate(":memory:".to_string()),
+            None,
         )));
 
         // Initialize a temporary scabbard state and set some values; this will pre-populate the DBs
@@ -189,6 +190,10 @@ mod tests {
             let mut state = ScabbardState::new(
                 &paths.state_db_path,
                 TEMP_DB_SIZE,
+                #[cfg(feature = "metrics")]
+                "svc0".to_string(),
+                #[cfg(feature = "metrics")]
+                "vzrQS-rvwf4".to_string(),
                 receipt_store.clone(),
                 vec![],
             )
@@ -354,7 +359,7 @@ mod tests {
         // This is deleted when dropped
         _temp_dir: TempDir,
         pub state_db_path: PathBuf,
-        #[cfg(not(feature = "diesel-receipt-store"))]
+        #[cfg(not(feature = "receipt-store"))]
         pub receipt_db_path: PathBuf,
     }
 
@@ -366,7 +371,7 @@ mod tests {
             let state_db_path =
                 compute_db_path(MOCK_SERVICE_ID, MOCK_CIRCUIT_ID, temp_dir.path(), "-state")
                     .expect("Failed to compute DB paths");
-            #[cfg(not(feature = "diesel-receipt-store"))]
+            #[cfg(not(feature = "receipt-store"))]
             let receipt_db_path = compute_db_path(
                 MOCK_SERVICE_ID,
                 MOCK_CIRCUIT_ID,
@@ -377,7 +382,7 @@ mod tests {
             Self {
                 _temp_dir: temp_dir,
                 state_db_path,
-                #[cfg(not(feature = "diesel-receipt-store"))]
+                #[cfg(not(feature = "receipt-store"))]
                 receipt_db_path,
             }
         }
@@ -486,7 +491,7 @@ mod tests {
         }
     }
 
-    #[cfg(all(feature = "diesel-receipt-store", feature = "sqlite"))]
+    #[cfg(all(feature = "receipt-store", feature = "sqlite"))]
     fn create_connection_pool_and_migrate(
         connection_string: String,
     ) -> Pool<ConnectionManager<diesel::SqliteConnection>> {
