@@ -16,7 +16,7 @@ use std::collections::{HashMap, HashSet, VecDeque};
 use std::convert::TryFrom;
 use std::fmt;
 use std::path::Path;
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 use std::str::FromStr;
 use std::sync::{
     mpsc::{channel, Receiver, RecvTimeoutError, Sender},
@@ -25,9 +25,9 @@ use std::sync::{
 use std::time::{Duration, Instant, SystemTime};
 
 use protobuf::Message;
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 use sawtooth::receipt::store::ReceiptStore;
-#[cfg(not(feature = "diesel-receipt-store"))]
+#[cfg(not(feature = "receipt-store"))]
 use sawtooth::store::receipt_store::TransactionReceiptStore;
 use sawtooth_sabre::{
     handler::SabreTransactionHandler, ADMINISTRATORS_SETTING_ADDRESS, ADMINISTRATORS_SETTING_KEY,
@@ -66,10 +66,10 @@ const ITER_CACHE_SIZE: usize = 64;
 const COMPLETED_BATCH_INFO_ITER_RETRY_MILLIS: u64 = 100;
 const DEFAULT_BATCH_HISTORY_SIZE: usize = 100;
 
-#[cfg(not(feature = "diesel-receipt-store"))]
+#[cfg(not(feature = "receipt-store"))]
 type ScabbardReceiptStore = Arc<RwLock<TransactionReceiptStore>>;
 
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 type ScabbardReceiptStore = Arc<RwLock<dyn ReceiptStore>>;
 
 /// Iterator over entries in a Scabbard service's state
@@ -83,6 +83,10 @@ pub struct ScabbardState {
     receipt_store: ScabbardReceiptStore,
     pending_changes: Option<(String, Vec<TransactionReceipt>)>,
     event_subscribers: Vec<Box<dyn StateSubscriber>>,
+    #[cfg(feature = "metrics")]
+    service_id: String,
+    #[cfg(feature = "metrics")]
+    circuit_id: String,
     batch_history: BatchHistory,
 }
 
@@ -90,6 +94,8 @@ impl ScabbardState {
     pub fn new(
         state_db_path: &Path,
         state_db_size: usize,
+        #[cfg(feature = "metrics")] service_id: String,
+        #[cfg(feature = "metrics")] circuit_id: String,
         receipt_store: ScabbardReceiptStore,
         admin_keys: Vec<String>,
     ) -> Result<Self, ScabbardStateError> {
@@ -149,7 +155,7 @@ impl ScabbardState {
             .map_err(|err| ScabbardStateError(format!("failed to start executor: {}", err)))?;
 
         // initialize committed_batches metric
-        counter!("splinter.scabbard.committed_batches", 0);
+        counter!("splinter.scabbard.committed_batches", 0, "service" => format!("{}::{}", &circuit_id, &service_id));
 
         Ok(ScabbardState {
             db,
@@ -159,6 +165,10 @@ impl ScabbardState {
             receipt_store,
             pending_changes: None,
             event_subscribers: vec![],
+            #[cfg(feature = "metrics")]
+            service_id,
+            #[cfg(feature = "metrics")]
+            circuit_id,
             batch_history: BatchHistory::new(),
         })
     }
@@ -315,7 +325,7 @@ impl ScabbardState {
                     .map(StateChangeEvent::try_from)
                     .collect::<Result<Vec<_>, _>>()?;
 
-                #[cfg(not(feature = "diesel-receipt-store"))]
+                #[cfg(not(feature = "receipt-store"))]
                 self.receipt_store
                     .write()
                     .map_err(|err| {
@@ -332,7 +342,7 @@ impl ScabbardState {
                         ))
                     })?;
 
-                #[cfg(feature = "diesel-receipt-store")]
+                #[cfg(feature = "receipt-store")]
                 self.receipt_store
                     .write()
                     .map_err(|err| {
@@ -363,7 +373,7 @@ impl ScabbardState {
                 }
 
                 self.batch_history.commit(&signature);
-                counter!("splinter.scabbard.committed_batches", 1);
+                counter!("splinter.scabbard.committed_batches", 1, "service" => format!("{}::{}", self.circuit_id, self.service_id));
                 Ok(())
             }
             None => Err(ScabbardStateError("no pending changes to commit".into())),
@@ -387,9 +397,9 @@ impl ScabbardState {
     }
 
     pub fn get_events_since(&self, event_id: Option<String>) -> Result<Events, ScabbardStateError> {
-        #[cfg(not(feature = "diesel-receipt-store"))]
+        #[cfg(not(feature = "receipt-store"))]
         let events = Events::new(self.receipt_store.clone(), event_id);
-        #[cfg(feature = "diesel-receipt-store")]
+        #[cfg(feature = "receipt-store")]
         let events = Events::new(self.receipt_store.clone(), event_id);
         events
     }
@@ -404,13 +414,13 @@ impl ScabbardState {
 }
 
 /// The possible connection types and identifiers passed to the migrate command
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 pub enum ConnectionUri {
     Postgres(String),
     Sqlite(String),
 }
 
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 impl FromStr for ConnectionUri {
     type Err = ScabbardStateError;
 
@@ -519,7 +529,7 @@ enum EventQuery {
     Exhausted,
 }
 
-#[cfg(not(feature = "diesel-receipt-store"))]
+#[cfg(not(feature = "receipt-store"))]
 /// An iterator that wraps the `TransactionReceiptStore` and returns `StateChangeEvent`s using an
 /// in-memory cache.
 pub struct Events {
@@ -528,7 +538,7 @@ pub struct Events {
     cache: VecDeque<StateChangeEvent>,
 }
 
-#[cfg(not(feature = "diesel-receipt-store"))]
+#[cfg(not(feature = "receipt-store"))]
 impl Events {
     fn new(
         transaction_receipt_store: Arc<RwLock<TransactionReceiptStore>>,
@@ -582,7 +592,7 @@ impl Events {
     }
 }
 
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 /// An iterator that wraps the `ReceiptStore` and returns `StateChangeEvent`s using an
 /// in-memory cache.
 pub struct Events {
@@ -591,7 +601,7 @@ pub struct Events {
     cache: VecDeque<StateChangeEvent>,
 }
 
-#[cfg(feature = "diesel-receipt-store")]
+#[cfg(feature = "receipt-store")]
 impl Events {
     fn new(
         receipt_store: Arc<RwLock<dyn ReceiptStore>>,
@@ -976,16 +986,16 @@ mod tests {
     use std::path::PathBuf;
 
     use cylinder::{secp256k1::Secp256k1Context, Context};
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     use diesel::{
         r2d2::{ConnectionManager, Pool},
         sqlite::SqliteConnection,
     };
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     use sawtooth::migrations::run_sqlite_migrations;
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     use sawtooth::receipt::store::diesel::DieselReceiptStore;
-    #[cfg(not(feature = "diesel-receipt-store"))]
+    #[cfg(not(feature = "receipt-store"))]
     use sawtooth::store::lmdb::LmdbOrderedStore;
     use tempdir::TempDir;
     use transact::{
@@ -1001,7 +1011,7 @@ mod tests {
     /// Verify that an empty receipt store returns an empty iterator
     #[test]
     fn empty_event_iterator() {
-        #[cfg(not(feature = "diesel-receipt-store"))]
+        #[cfg(not(feature = "receipt-store"))]
         {
             let paths = StatePaths::new("empty_event_iterator");
 
@@ -1011,7 +1021,7 @@ mod tests {
                         .expect("Failed to create LMDB store"),
                 ))));
 
-            #[cfg(not(feature = "diesel-receipt-store"))]
+            #[cfg(not(feature = "receipt-store"))]
             // Test without a specified start
             let all_events = Events::new(transaction_receipt_store.clone(), None)
                 .expect("failed to get iterator for all events");
@@ -1023,11 +1033,11 @@ mod tests {
             );
         }
 
-        #[cfg(feature = "diesel-receipt-store")]
+        #[cfg(feature = "receipt-store")]
         {
             let pool = create_connection_pool_and_migrate(":memory:".to_string());
 
-            let receipt_store = Arc::new(RwLock::new(DieselReceiptStore::new(pool)));
+            let receipt_store = Arc::new(RwLock::new(DieselReceiptStore::new(pool, None)));
 
             // Test without a specified start
             let all_events =
@@ -1054,7 +1064,7 @@ mod tests {
             .map(|receipt| receipt.transaction_id.clone())
             .collect::<Vec<_>>();
 
-        #[cfg(not(feature = "diesel-receipt-store"))]
+        #[cfg(not(feature = "receipt-store"))]
         {
             let paths = StatePaths::new("event_iterator");
 
@@ -1087,11 +1097,11 @@ mod tests {
             assert_eq!(some_event_ids, receipt_ids[1..].to_vec());
         }
 
-        #[cfg(feature = "diesel-receipt-store")]
+        #[cfg(feature = "receipt-store")]
         {
             let pool = create_connection_pool_and_migrate(":memory:".to_string());
 
-            let receipt_store = Arc::new(RwLock::new(DieselReceiptStore::new(pool)));
+            let receipt_store = Arc::new(RwLock::new(DieselReceiptStore::new(pool, None)));
 
             receipt_store
                 .write()
@@ -1129,7 +1139,7 @@ mod tests {
         // Initialize state
         let paths = StatePaths::new("get_state_at_address");
 
-        #[cfg(not(feature = "diesel-receipt-store"))]
+        #[cfg(not(feature = "receipt-store"))]
         let receipt_store = Arc::new(RwLock::new(TransactionReceiptStore::new(Box::new(
             LmdbOrderedStore::new(
                 &StatePaths::new("state_at_address").receipt_db_path,
@@ -1137,14 +1147,23 @@ mod tests {
             )
             .expect("Failed to create LMDB store"),
         ))));
-        #[cfg(feature = "diesel-receipt-store")]
+        #[cfg(feature = "receipt-store")]
         let receipt_store = Arc::new(RwLock::new(DieselReceiptStore::new(
             create_connection_pool_and_migrate(":memory:".to_string()),
+            None,
         )));
 
-        let mut state =
-            ScabbardState::new(&paths.state_db_path, TEMP_DB_SIZE, receipt_store, vec![])
-                .expect("Failed to initialize state");
+        let mut state = ScabbardState::new(
+            &paths.state_db_path,
+            TEMP_DB_SIZE,
+            #[cfg(feature = "metrics")]
+            "svc0".to_string(),
+            #[cfg(feature = "metrics")]
+            "vzrQS-rvwf4".to_string(),
+            receipt_store,
+            vec![],
+        )
+        .expect("Failed to initialize state");
 
         // Set a value in state
         let address = "abcdef".to_string();
@@ -1203,7 +1222,7 @@ mod tests {
     fn get_state_with_prefix() {
         let paths = StatePaths::new("get_state_at_address");
 
-        #[cfg(not(feature = "diesel-receipt-store"))]
+        #[cfg(not(feature = "receipt-store"))]
         let receipt_store = Arc::new(RwLock::new(TransactionReceiptStore::new(Box::new(
             LmdbOrderedStore::new(
                 &StatePaths::new("state_with_prefix").receipt_db_path,
@@ -1211,14 +1230,23 @@ mod tests {
             )
             .expect("Failed to create LMDB store"),
         ))));
-        #[cfg(feature = "diesel-receipt-store")]
+        #[cfg(feature = "receipt-store")]
         let receipt_store = Arc::new(RwLock::new(DieselReceiptStore::new(
             create_connection_pool_and_migrate(":memory:".to_string()),
+            None,
         )));
 
-        let mut state =
-            ScabbardState::new(&paths.state_db_path, TEMP_DB_SIZE, receipt_store, vec![])
-                .expect("Failed to initialize state");
+        let mut state = ScabbardState::new(
+            &paths.state_db_path,
+            TEMP_DB_SIZE,
+            #[cfg(feature = "metrics")]
+            "svc0".to_string(),
+            #[cfg(feature = "metrics")]
+            "vzrQS-rvwf4".to_string(),
+            receipt_store,
+            vec![],
+        )
+        .expect("Failed to initialize state");
 
         // Set some values in state
         let prefix = "abcdef".to_string();
@@ -1285,7 +1313,7 @@ mod tests {
     struct StatePaths {
         _temp_dir_handle: TempDir,
         pub state_db_path: PathBuf,
-        #[cfg(not(feature = "diesel-receipt-store"))]
+        #[cfg(not(feature = "receipt-store"))]
         pub receipt_db_path: PathBuf,
     }
 
@@ -1293,12 +1321,12 @@ mod tests {
         fn new(prefix: &str) -> Self {
             let temp_dir = TempDir::new(prefix).expect("Failed to create temp dir");
             let state_db_path = temp_dir.path().join("state.lmdb");
-            #[cfg(not(feature = "diesel-receipt-store"))]
+            #[cfg(not(feature = "receipt-store"))]
             let receipt_db_path = temp_dir.path().join("receipts.lmdb");
             Self {
                 _temp_dir_handle: temp_dir,
                 state_db_path,
-                #[cfg(not(feature = "diesel-receipt-store"))]
+                #[cfg(not(feature = "receipt-store"))]
                 receipt_db_path,
             }
         }
@@ -1315,7 +1343,7 @@ mod tests {
         }
     }
 
-    #[cfg(feature = "diesel-receipt-store")]
+    #[cfg(feature = "receipt-store")]
     fn create_connection_pool_and_migrate(
         connection_string: String,
     ) -> Pool<ConnectionManager<SqliteConnection>> {
